@@ -22,17 +22,18 @@ class Post(models.Model):
     Modelo que define un post.
     """
 
-    title = models.CharField(_('Title'), max_length=255)
-    slug = models.SlugField(max_length=255)
-    text = models.TextField(_('Text'))
+    title = models.CharField(_(u'Title'), max_length=255)
+    slug = models.SlugField(_(u'Slug'), max_length=255)
+    text = models.TextField(_(u'Text'))
     tags = TagField()
-    image = models.ImageField(_('Image'), upload_to='images/posts', blank=True)
-    hits = models.IntegerField(_('Hits'), blank=True, default=1)
-    creation_date = models.DateTimeField(_('Creation date'))
+    image = models.ImageField(_(u'Image'), upload_to='images/posts', blank=True)
+    hits = models.IntegerField(_(u'Hits'), blank=True, default=1)
+    creation_date = models.DateTimeField(_(u'Creation date'))
     user = models.ForeignKey(User, related_name="post_from")
     highlighted =  models.BooleanField(_('Highlighted'), blank=True)
-    status =  models.BooleanField(_('Status'), default=True)
-    thread_id = models.CharField(max_length=32, blank=True) # DISQUS
+    status =  models.BooleanField(_(u'Status'), default=True)
+    thread_id = models.CharField(_(u'Disqus thread id'), max_length=32, blank=True) # DISQUS
+    lang = models.CharField(_(u'Language of the post'), max_length=32, blank=True, null=True)
 
     if "rgallery" in conf.INSTALLED_APPS:
         from rgallery.models import Photo, Video
